==> snipe-it-6.3.0.zip: snipe-it-6.3.0/resources/lang/tr-TR/admin/custom_fields/general.php <==
<?php

return [
    'custom_fields'		        => 'Özel alanlar',
    'manage'                    => 'Yönet',
    'field'		                => 'Alan',
    'about_fieldsets_title'		=> 'Alan kümeleri hakkında',
    'about_fieldsets_text'		=> 'Alan kümeleri, belirli varlık model türleri için sıklıkla yeniden kullanılan özel alan grupları oluşturmanızı sağlar.',
    'custom_format'             => 'Özel Regex biçimi...',
    'encrypt_field'      	        => 'Veritabanındaki bu alanın değerini şifreleme',
    'encrypt_field_help'      => 'UYARI: Bir alanı şifrelemek, onu aranamaz hale getirir.',
    'encrypted'      	        => 'Şifreli',
    'fieldset'      	        => 'Alan kümesi',
    'qty_fields'      	      => 'Miktar alanları',
    'fieldsets'      	        => 'Alan kümeleri',
    'fieldset_name'           => 'Alan kümesi adı',
    'field_name'              => 'Alan Adı',
    'field_values'            => 'Alan değerleri',
    'field_values_help'       => 'Seçilebilir seçenekler, her satıra bir tane ekleyin. İlk satır dışındaki boş satırlar yoksayılacaktır.',
    'field_element'           => 'Form öğesi',
    'field_element_short'     => 'Öğe',
    'field_format'            => 'Düzen',
    'field_custom_format'     => 'Özel biçim',
    'field_custom_format_help'     => 'Bu alan doğrulama için bir regex ifadesi kullanmanıza izin verir. Bu alan "regex:" ile başlamalı - örneğin, özel alan değerinin geçerli bir IMEI (15 basamaklı) olmasını sağlamak için <code>regex:/^[0-9]{15}$/</code> şeklinde kodlamalısınız.',
    'required'   		          => 'Gerekli',
    'req'   		              => 'Talep.',
    'used_by_models'   		    => 'Modellerle Kullanılmıştır',
    'order'   		            => 'Sipariş',
    'create_fieldset'         => 'Yeni alan kümesi',
    'update_fieldset'         => 'Fieldset\'i güncelle',
    'fieldset_does_not_exist'   => 'Fieldset :id yok',
    'fieldset_updated'         => 'Fieldset güncellendi',
    'create_fieldset_title' => 'Yeni bir alan kümesi oluştur',
    'create_field'            => 'Yeni özel alan',
    'create_field_title' => 'Yeni bir özel alan oluştur',
    'value_encrypted'      	        => 'Bu alanın değeri veritabanında şifrelidir. Yalnızca yönetici kullanıcıları şifresi çözülen değeri görüntüleyebilir',
    'show_in_email'     => 'Bu hane içerisindeki bilgi "Zimmet e-postası" içerisinde kullanıcıya gönderilsinmi? Şifrelenmiş hanelerin içerisindeki bilgiler gönderilemez.',
    'show_in_email_short'     => 'E-postalara dahil edin.',
    'help_text' => 'Yardım Metni',
    'help_text_description' => 'Bu isteğe bağlı metin alanı, varlık düzenleme esnasında formdaki öğelere bağlam kazandırmak amacıyla öğelerin altında gözükecektir.',
    'about_custom_fields_title' => 'Özel Alanlar Hakkında',
    'about_custom_fields_text' => 'Özel alanlar, varlıklara istediğiniz özellikleri eklemenize olanak sağlar.',
    'add_field_to_fieldset' => 'Alan Kümesine Alan Ekle',
    'make_optional' => 'Gerekli - isteğe bağlı yapmak için tıklayın',
    'make_required' => 'İsteğe bağlı - gerekli yapmak için tıklayın',
    'reorder' => 'Yeniden Sırala',
    'db_field' => 'Veri Tabanı Sütunları',
    'db_convert_warning' => 'UYARI. Bu alan, özel alanlar tablosunda <code>:db_column</code> olarak bulunur, ancak <code>:expected</code> olmalıdır.',
    'is_unique' => 'Bu değer tüm varlıklarda benzersiz olmalıdır',
    'unique' => 'Benzersiz',
    'display_in_user_view' => 'Teslim alınan kullanıcının bu değerleri Atanan Varlıkları Görüntüle sayfasında görüntülemesine izin ver',
    'display_in_user_view_table' => 'Kullanıcı tarafından görülebilir',
    'auto_add_to_fieldsets' => 'Bunu her yeni alan kümesine otomatik olarak ekle',
    'add_to_preexisting_fieldsets' => 'Mevcut alan kümelerine ekle',
    'show_in_listview' => 'Varsayılan olarak liste görünümlerinde göster. Yetkili kullanıcılar sütun seçici aracılığıyla göstermeye/gizlemeye devam edebilecektir',
    'show_in_listview_short' => 'Listelerde göster',
    'show_in_requestable_list_short' => 'Talep edilebilir varlıklar listesinde göster',
    'show_in_requestable_list' => 'Değeri talep edilebilir varlıklar listesinde gösterin. Şifreli alanlar gösterilmeyecek',
    'encrypted_options' => 'Bu alan şifrelendiğinden bazı görüntüleme seçenekleri kullanılamayacaktır.',

];

==> snipe-it-8.0.1.zip: snipe-it-8.0.1/resources/lang/tr-TR/admin/custom_fields/general.php <==
<?php

return [
    'custom_fields'		        => 'Özel alanlar',
    'manage'                    => 'Yönet',
    'field'		                => 'Alan',
    'about_fieldsets_title'		=> 'Alan kümeleri hakkında',
    'about_fieldsets_text'		=> 'Alan kümeleri, belirli varlık model türleri için sıklıkla yeniden kullanılan özel alan grupları oluşturmanızı sağlar.',
    'custom_format'             => 'Özel Regex biçimi...',
    'encrypt_field'      	        => 'Veritabanındaki bu alanın değerini şifreleme',
    'encrypt_field_help'      => 'UYARI: Bir alanı şifrelemek, onu aranamaz hale getirir.',
    'encrypted'      	        => 'Şifreli',
    'fieldset'      	        => 'Alan kümesi',
    'qty_fields'      	      => 'Miktar alanları',
    'fieldsets'      	        => 'Alan kümeleri',
    'fieldset_name'           => 'Alan kümesi adı',
    'field_name'              => 'Alan Adı',
    'field_values'            => 'Alan değerleri',
    'field_values_help'       => 'Seçilebilir seçenekler, her satıra bir tane ekleyin. İlk satır dışındaki boş satırlar yoksayılacaktır.',
    'field_element'           => 'Form öğesi',
    'field_element_short'     => 'Öğe',
    'field_format'            => 'Düzen',
    'field_custom_format'     => 'Özel biçim',
    'field_custom_format_help'     => 'Bu alan doğrulama için bir regex ifadesi kullanmanıza izin verir. Bu alan "regex:" ile başlamalı - örneğin, özel alan değerinin geçerli bir IMEI (15 basamaklı) olmasını sağlamak için <code>regex:/^[0-9]{15}$/</code> şeklinde kodlamalısınız.',
    'required'   		          => 'Gerekli',
    'req'   		              => 'Talep.',
    'used_by_models'   		    => 'Modellerle Kullanılmıştır',
    'order'   		            => 'Sipariş',
    'create_fieldset'         => 'Yeni alan kümesi',
    'update_fieldset'         => 'Fieldset\'i güncelle',
    'fieldset_does_not_exist'   => 'Fieldset :id yok',
    'fieldset_updated'         => 'Fieldset güncellendi',
    'create_fieldset_title' => 'Yeni bir alan kümesi oluştur',
    'create_field'            => 'Yeni özel alan',
    'create_field_title' => 'Yeni bir özel alan oluştur',
    'value_encrypted'      	        => 'Bu alanın değeri veritabanında şifrelidir. Yalnızca yönetici kullanıcıları şifresi çözülen değeri görüntüleyebilir',
    'show_in_email'     => 'Bu hane içerisindeki bilgi "Zimmet e-postası" içerisinde kullanıcıya gönderilsinmi? Şifrelenmiş hanelerin içerisindeki bilgiler gönderilemez.',
    'show_in_email_short' => 'E-postalara dahil edin',
    'help_text' => 'Yardım Metni',
    'help_text_description' => 'Bu isteğe bağlı metin alanı, varlık düzenleme esnasında formdaki öğelere bağlam kazandırmak amacıyla öğelerin altında gözükecektir.',
    'about_custom_fields_title' => 'Özel Alanlar Hakkında',
    'about_custom_fields_text' => 'Özel alanlar, varlıklara istediğiniz özellikleri eklemenize olanak sağlar.',
    'add_field_to_fieldset' => 'Alan Kümesine Alan Ekle',
    'make_optional' => 'Gerekli - isteğe bağlı yapmak için tıklayın',
    'make_required' => 'İsteğe bağlı - gerekli yapmak için tıklayın',
    'reorder' => 'Yeniden Sırala',
    'db_field' => 'Veri Tabanı Sütunları',
    'db_convert_warning' => 'UYARI. Bu alan, özel alanlar tablosunda <code>:db_column</code> olarak bulunur, ancak <code>:expected</code> olmalıdır.',
    'is_unique' => 'Bu değer tüm varlıklarda benzersiz olmalıdır',
    'unique' => 'Benzersiz',
    'display_in_user_view' => 'Teslim alınan kullanıcının bu değerleri Atanan Varlıkları Görüntüle sayfasında görüntülemesine izin ver',
    'display_in_user_view_table' => 'Kullanıcı tarafından görülebilir',
    'auto_add_to_fieldsets' => 'Bunu her yeni alan kümesine otomatik olarak ekle',
    'add_to_preexisting_fieldsets' => 'Mevcut alan kümelerine ekle',
    'show_in_listview' => 'Varsayılan olarak liste görünümlerinde göster. Yetkili kullanıcılar sütun seçici aracılığıyla göstermeye/gizlemeye devam edebilecektir',
    'show_in_listview_short' => 'Listelerde göster',
    'show_in_requestable_list_short' => 'Talep edilebilir varlıklar listesinde göster',
    'show_in_requestable_list' => 'Değeri talep edilebilir varlıklar listesinde gösterin. Şifreli alanlar gösterilmeyecek',
    'encrypted_options' => 'Bu alan şifrelendiğinden bazı görüntüleme seçenekleri kullanılamayacaktır.',
    'display_checkin' => 'Display in checkin forms',
    'display_checkout' => 'Display in checkout forms',

];
